% Robust regression routines for reducing the OERSTED sampling rate.
%
% These m-files perform robust polynomial regression with resampling
%		estimates of the SE of the resulting regression
%		function.
%
% biwght:	Tukey's biweight (bisquare) weight function
%
% bldCheb:	builds the "design" matrix for regression against
%		Chebychev polynomials
%
% bldPoly:	builds the "design" matrix for regression against
%		ordinary polynomials
%
% hampel:	Weight function corresponding to Hampel's redescending 
%		(3-part) weight function.
%
% huber:	Weight function corresponding to Huber's 
%		influence function
%
% irwls:	iteratively re-weighted least squares regression
%
% l1rgres:	minimum l_1-norm regression using linear programming
%		WARNING: Matlab's lp algorithm is unstable and
%		unreliable
%
% l1test:	comparison of l1rgres and irwls using l1wght 
%		(MATLAB's linear programming routines aren't very
%		good).
%
% l1wght:	weights to approximate minimum l_1 norm using irwls
%
% magsTest:	sample script running rwlsBoot on MAGSAT data
%
% oerTest:	sample script running rwlsBoot on OERSTED ground
%		test data
%
% plotWght:	plot the influence functions and the corresponding
%		weight functions for the robust weights in this
%		package
%
% regRand:	sample script running rwlsBoot on synthetic data
%
% rwlsBoot:	iteratively reweighted least squares regression, 
%		with Bootstrap estimates of the standard deviation of
%		linear functionals of the regression coefficients
%
% testSe:	test the bias in  iteratively reweighted least squares
%		estimates, and the bias in the resampling estimates
%		of the standard error of the estimates	
%
% wls:		weighted least squares
%
% wrongMod:	test the dependence of the bias of the irwls procedures
%		upon the true degree of the model versus the degree
%		of the fitted polynomial
%
%
% P.B. Stark  	stark@stat.berkeley.edu
% 27 July 1997


