% script oerTest
% loads the OERSTED ground test data and fits parts of it
% using robust regression, with bootstrap uncertainty estimates.
% Plots estimates +- 2SE, color-coded for coverage of the datum
%
%
% P.B. Stark  stark@stat.berkeley.edu
% 26 July 1997.

% parameters
ndat = 25;			% number of data in each window
mid = ceil(ndat/2);		% half-width of window
frst = 500;			% window to start with
bdim = 4;			% dimension of model (cubic)
ftype = 'bldCheb';		% subroutine to build design matrix
scalMeth = 'one-step';		% way to estimate the scale
wght1 = 'biwght';		% biweight is weight function 1
par1 = 8;			% parameter of weight
wght2 = 'l1wght';		% second weight function
par2 = 1;
wght3 = 'hampel';		% number 3 weight fn.
par3 = [2 4 8];
nints = 3;			% number of time intervals of length
				% ndat to compute estimates for
nboot = 100;			% number of bootstrap samples
iplsym = 'r+';			% plotting symbols and colors for the
jplsym = 'b+';			% error bars
kplsym = 'c+';			%

% load calibration data

load fm1.dat -ascii	% the OERSTED data
% the first column is a pseudo-time; the next three are measurements
[m,n] = size(fm1);
t = 1:m;

x = [1:ndat];
X = feval(ftype,ndat,bdim-1);	% build design matrix
XP = X(mid,:);			% prediction vector for middle sample

ncoveri = 0;
ncoverj = 0;
ncoverk = 0;
titlab = ['1' '2' '3'];
for i=1:nints,
	for j = 1:3,
		start = (frst+i-1)*ndat + 1;
		y = fm1(start : start+ndat-1, j+1);
		figure
		plot(x+start-1,y,'go')
		title(['OERSTED ground data: 18 Mar 1996, component '... 
			titlab(j)])
		xlabel('Sample')
		hold
		[bbi, resbi, sebi ] = rwlsBoot(y,X,XP,nboot,wght1,par1, ...
			scalMeth);		% irwls w/ weight 1
		[bbj, resbj, sebj ] = rwlsBoot(y,X,XP,nboot,wght2,par2, ...
			scalMeth);		% irwls weight 2
		[bbk, resbk, sebk ] = rwlsBoot(y,X,XP,nboot,wght3,par3, ...
			scalMeth);		% irwls weight 3		
		[bols, resols, wssols] = wls(y, X, ones(size(y))); 
			% ordinary least-squares
%
		plot(x+start-1, X*bols,'w')
		plot(x+start-1, X*bbi,'r--')
		plot(x+start-1, X*bbj,'b-.')
		plot(x+start-1, X*bbk,'c:')

		ncoveri = ncoveri + (abs(y(mid) - XP*bbi) <= 2*sebi);
		ncoverj = ncoverj + (abs(y(mid) - XP*bbj) <= 2*sebj);
		ncoverk = ncoverk + (abs(y(mid) - XP*bbk) <= 2*sebk);
		plot(x(mid)+start-1, XP*bbi + 2*sebi,iplsym)
		plot(x(mid)+start-1, XP*bbi - 2*sebi,iplsym)
		plot(x(mid)+start-1, XP*bbj + 2*sebj,jplsym)
		plot(x(mid)+start-1, XP*bbj - 2*sebj,jplsym)
		plot(x(mid)+start-1, XP*bbk + 2*sebk,kplsym)
		plot(x(mid)+start-1, XP*bbk - 2*sebk,kplsym)	
	end;
end;

coveri = ncoveri/(3*nints)
coverj = ncoverj/(3*nints)
coverk = ncoverk/(3*nints)

