% script regRand
% sets up dummy regression problems with noise either
% Normal
% Lognormal*uniform(-1,1)
% Lognormal w/ random sign
% Lognormal/Uniform(0,1)
% mixture of Normal and lognormal
%
% P.B. Stark stark@stat.berkeley.edu
% 26 July 1997
%

% parameters
mix = 0.02;			% mixture fraction of lognormal
nrep = 1;			% number of replications
ndat = 100;			% number of data
snr = 5;			% signal to noise ratio
bdim = 5;			% dimension of model
sc = 'one-step';		% procedure for estimating scale of
				% the residuals			
ftype = 'bldCheb';		% subroutine to build design matrix
wght1 = 'biwght';		% subroutine for robust weights
param1 = 8;			% parameter for the weight
wght2 = 'hampel';
param2 = [2 4 8];
wght3 = 'l1wght';
param3 = 1;
nboot = 1;			% number of bootstrap replications


x = [1:ndat];
X = feval(ftype,ndat,bdim-1);	% build design matrix

% generate random b
b = 10*randn(bdim,1);		% normal (for now)

yt = X*b;
normy = norm(yt);		% nominal signal level
 noise = 2*normy/snr*(rand(ndat,nrep) -0.5).* ...	% U*lognormal
	exp(randn(ndat,nrep));
% noise = normy/snr*randn(ndat,nrep)./rand(ndat,nrep);  % "slash"
% noise = normy/snr*randn(ndat,nrep); 			% normal
%  noise = normy/snr*exp(randn(ndat,nrep))*2 ...		% lognormal w/ rand
%		.*((rand(ndat,nrep) >= 0)-0.5);		% sign
%
% the next few lines are for the mixture of a signed lognormal and 
% a normal, with mixture fraction _mix_ of the lognormal
%umat = rand(ndat,nrep);
%noise = normy/snr*randn(ndat,nrep);
%lgn = normy/snr*exp(randn(ndat,nrep))*2 ...		% lognormal w/ rand
%	.*((rand(ndat,nrep) >= 0)-0.5);		
%noise(umat < mix) = lgn(umat < mix);

for i=1:nrep,

	figure
	plot(x,yt,'g')
	title('Random Regression Test: Uniform(-1,1)*Lognormal Noise')
	hold
	y = yt + noise(:,i);
	plot(x,y,'g+')

% 	[bl1, l1res, l1msft] = l1rgres(y,X,0,'lp');	% minimum l_1 regression

	[b1, res1, se1, it1 ] = rwlsBoot(y,X,X,nboot,wght1,param1,sc);
	[b2, res2, se2, it2 ] = rwlsBoot(y,X,X,nboot,wght2,param2,sc);
	[b3, res3, se3, it3 ] = rwlsBoot(y,X,X,nboot,wght3,param3,sc);
	[bols, resols, wssols] = wls(y, X, ones(ndat,1)); % ordinary least-squares

	plot(x, X*b1,'r')
	plot(x, X*b2,'y')
	plot(x, X*b3,'b')
	plot(x, X*bols,'w')

	disp(['iterations: weight 1 ' num2str(it1) ...
		', weight 2 ' num2str(it2) ...
		', weight 3 ' num2str(it3) ...
		])
end
